API reference
=============

fortdepend.fort\_depend module
------------------------------

.. automodule:: fortdepend.fort_depend
    :members:
    :undoc-members:
    :show-inheritance:

fortdepend.graph module
-----------------------

.. automodule:: fortdepend.graph
    :members:
    :undoc-members:
    :show-inheritance:

fortdepend.preprocessor module
------------------------------

.. automodule:: fortdepend.preprocessor
    :members:
    :undoc-members:
    :show-inheritance:

fortdepend.smartopen module
---------------------------

.. automodule:: fortdepend.smartopen
    :members:
    :undoc-members:
    :show-inheritance:

fortdepend.units module
-----------------------

.. automodule:: fortdepend.units
    :members:
    :undoc-members:
    :show-inheritance:
